==> pyside-setup-opensource-src-6.0.0.zip: pyside-setup-opensource-src-6.0.0/sources/pyside6/tests/QtCore/qcommandlineparser_test.py <==
#!/usr/bin/python

#############################################################################
##
## Copyright (C) 2017 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Unit tests for QCommandLineParser and QCommandLineOption'''

import ctypes
import os
import sys
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6.QtCore import *

class QCommandLineParserTest(unittest.TestCase):
    def testParser(self):
        app = QCoreApplication([])

        parser1 = QCommandLineParser()
        self.assertEqual(parser1.parse(["QtCore_qcommandlineparser_test", "file.txt"]), True)
        self.assertEqual(parser1.positionalArguments(), ["file.txt"])

        parser2 = QCommandLineParser()
        self.assertEqual(parser2.addOption(QCommandLineOption("b")), True)
        self.assertEqual(parser2.parse(["QtCore_qcommandlineparser_test", "-b"]), True)
        self.assertEqual(parser2.optionNames(), ["b"])
        self.assertEqual(parser2.isSet("b"), True)
        self.assertEqual(parser2.values("b"), [])
        self.assertEqual(parser2.positionalArguments(), [])

if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-6.2.9.zip: pyside-setup-opensource-src-6.2.9/sources/pyside6/tests/QtCore/qcommandlineparser_test.py <==
#!/usr/bin/python

#############################################################################
##
## Copyright (C) 2017 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''Unit tests for QCommandLineParser and QCommandLineOption'''

import ctypes
import os
import sys
import unittest

from pathlib import Path
sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6.QtCore import QCoreApplication, QCommandLineOption, QCommandLineParser


class QCommandLineParserTest(unittest.TestCase):
    def testParser(self):
        app = QCoreApplication([])

        parser1 = QCommandLineParser()
        self.assertEqual(parser1.parse(["QtCore_qcommandlineparser_test", "file.txt"]), True)
        self.assertEqual(parser1.positionalArguments(), ["file.txt"])

        parser2 = QCommandLineParser()
        self.assertEqual(parser2.addOption(QCommandLineOption("b")), True)
        self.assertEqual(parser2.parse(["QtCore_qcommandlineparser_test", "-b"]), True)
        self.assertEqual(parser2.optionNames(), ["b"])
        self.assertEqual(parser2.isSet("b"), True)
        self.assertEqual(parser2.values("b"), [])
        self.assertEqual(parser2.positionalArguments(), [])


if __name__ == '__main__':
    unittest.main()
